@@ -38,6 +38,7 @@ class CommittedFileSizeCheck(CommittedFileCheck):
     def get_problems(self):
         file_size = self.committed_file.get_file_size()
         extension = self.committed_file.get_extension()
+        is_framework = self.committed_file.get_framework()
         if file_size == -1:
             yield (
                 Severity.ERROR,
@@ -45,14 +46,15 @@ class CommittedFileSizeCheck(CommittedFileCheck):
                     self.committed_file.commit, self.committed_file.path)
             )
         condition = False if extension in config.get("commit_check.binary_file_legitimate_suffixes") else True
-        if file_size >= config.get("commit_check.commit_file_max_size") and condition:
-            yield (
-                Severity.ERROR,
-                '提交 {} 的文件 {} 大小超过 {}, 即 {} MB'.format(
-                    self.committed_file.commit, self.committed_file.path,
-                    config.get("commit_check.commit_file_max_size"),
-                    config.get("commit_check.commit_file_max_size") / 1024 / 1024)
-            )
+        if condition and is_framework:
+            if file_size >= config.get("commit_check.commit_file_max_size") and condition:
+                yield (
+                    Severity.ERROR,
+                    '提交 {} 的文件 {} 大小超过 {}, 即 {} MB'.format(
+                        self.committed_file.commit, self.committed_file.path,
+                        config.get("commit_check.commit_file_max_size"),
+                        config.get("commit_check.commit_file_max_size") / 1024 / 1024)
+                )
 
 
 class CommittedFileExtensionCheck(CommittedFileCheck):
